
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}

<div class="row">
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Base du site
            </div>
            <div class="panel-body">
                {{ form_row(form.company) }}
                {{ form_row(form.firstname) }}
                {{ form_row(form.lastname) }}
                {{ form_row(form.phone1) }}
                {{ form_row(form.phone2) }}
                {{ form_row(form.phone3) }}
                {{ form_row(form.emailFrom) }}
                {{ form_row(form.emailToMessage) }}
                {{ form_row(form.emailToShop) }}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                Editeur du site
            </div>
            <div class="panel-body">
                {{ form_row(form.editorCompany) }}
                {{ form_row(form.editorAddress) }}
                {{ form_row(form.editorCity) }}
                {{ form_row(form.editorPostal) }}
                {{ form_row(form.editorRcs) }}
                {{ form_row(form.editorTva) }}
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Adresse
            </div>
            <div class="panel-body">
                {{ form_row(form.address) }}
                {{ form_row(form.postal) }}
                {{ form_row(form.city) }}
                {{ form_row(form.country) }}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                Référencement local
            </div>
            <div class="panel-body">
                <div class="row">
                    <div class="col-md-6">
                        {{ form_row(form.latitude) }}
                    </div>
                    <div class="col-md-6">
                        {{ form_row(form.longitude) }}
                    </div>
                </div>
                {{ form_row(form.openingHours) }}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                Réseaux sociaux
            </div>
            <div class="panel-body">
                {{ form_row(form.facebook) }}
                {{ form_row(form.twitter) }}
                {{ form_row(form.instagram) }}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                Logo
            </div>
            <div class="panel-body">
                {{ form_row(form.image) }}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                CGV
            </div>
            <div class="panel-body">
                {{ form_row(form.cgv) }}
                {% if form.legalNoticeContent is defined %}
                    {{ form_row(form.legalNoticeContent) }}
                {% endif %}
                {% if form.privacyPolicyContent is defined %}
                    {{ form_row(form.privacyPolicyContent) }}
                {% endif %}
                {{ form_row(form.legalNoticeExtraParagraph) }}
                {{ form_row(form.privacyPolicyExtraParagraph) }}
                {{ form_row(form.committeeChampagneSiret) }}
                {{ form_row(form.committeeChampagneIdentifiant) }}
            </div>
        </div>
    </div>
</div>
{{ form_rest(form) }}
